==> linux-show-player_0.5.orig.tar.gz: linux-show-player-0.5/lisp/modules/presets/i18n/presets_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>Preset</name>
    <message>
        <location filename="../presets_ui.py" line="215"/>
        <source>Create Cue</source>
        <translation>Créer un cue</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="216"/>
        <source>Load on selected Cues</source>
        <translation>Charger les cues sélectionnés</translation>
    </message>
</context>
<context>
    <name>Presets</name>
    <message>
        <location filename="../presets_ui.py" line="364"/>
        <source>Presets</source>
        <translation>Pré-réglages</translation>
    </message>
    <message>
        <location filename="../presets.py" line="52"/>
        <source>Load preset</source>
        <translation>Charger un pré-réglage</translation>
    </message>
    <message>
        <location filename="../presets.py" line="56"/>
        <source>Save as preset</source>
        <translation>Sauvegarder un pré-réglage sous</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="52"/>
        <source>Cannot scan presets</source>
        <translation>Impossible d&apos;examiner les pré-réglages</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="60"/>
        <source>Error while deleting preset &quot;{}&quot;</source>
        <translation>Erreur lors de la suppression du pré-réglage &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="68"/>
        <source>Cannot load preset &quot;{}&quot;</source>
        <translation>Impossible de charger le pré-réglage &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="76"/>
        <source>Cannot save preset &quot;{}&quot;</source>
        <translation>Impossible de sauvegarder le pré-réglage &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="84"/>
        <source>Cannot rename preset &quot;{}&quot;</source>
        <translation>Impossible de renommer le pré-réglage &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="96"/>
        <source>Select Preset</source>
        <translation>Sélectionner le pré-réglage</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="109"/>
        <source>Preset already exists, overwrite?</source>
        <translation>Le pré-réglage existe déjà, l&apos;écraser ?</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="419"/>
        <source>Preset name</source>
        <translation>Nom du pré-réglage</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="211"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="212"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="213"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="214"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="217"/>
        <source>Export selected</source>
        <translation>Exporter le sélectionné</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="218"/>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="301"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="256"/>
        <source>The same name is already used!</source>
        <translation>Le même nom est déjà utilisé !</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="301"/>
        <source>Cannot create a cue from this preset: {}</source>
        <translation>Impossible de créer un cue depuis ce pré-réglage : {}</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="339"/>
        <source>Cannot export correctly.</source>
        <translation>Impossible d&apos;exporter correctement</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="351"/>
        <source>Some presets already exists, overwrite?</source>
        <translation>Certains pré-réglages existent déjà, les écraser ?</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="364"/>
        <source>Cannot import correctly.</source>
        <translation>Impossible d&apos;importer correctement.</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="420"/>
        <source>Cue type</source>
        <translation>Type de cue</translation>
    </message>
</context>
</TS>

==> linux-show-player_0.5.3.orig.tar.gz: linux-show-player-0.5.3/lisp/modules/presets/i18n/presets_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>Preset</name>
    <message>
        <location filename="../presets_ui.py" line="215"/>
        <source>Create Cue</source>
        <translation>Créer une cue</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="216"/>
        <source>Load on selected Cues</source>
        <translation>Charger les cues sélectionnées</translation>
    </message>
</context>
<context>
    <name>Presets</name>
    <message>
        <location filename="../presets_ui.py" line="364"/>
        <source>Presets</source>
        <translation>Préréglages</translation>
    </message>
    <message>
        <location filename="../presets.py" line="52"/>
        <source>Load preset</source>
        <translation>Charger un préréglage</translation>
    </message>
    <message>
        <location filename="../presets.py" line="56"/>
        <source>Save as preset</source>
        <translation>Sauvegarder un préréglage sous</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="52"/>
        <source>Cannot scan presets</source>
        <translation>Impossible d&apos;examiner les préréglages</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="60"/>
        <source>Error while deleting preset &quot;{}&quot;</source>
        <translation>Erreur lors de la suppression du préréglage &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="68"/>
        <source>Cannot load preset &quot;{}&quot;</source>
        <translation>Impossible de charger le préréglage &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="76"/>
        <source>Cannot save preset &quot;{}&quot;</source>
        <translation>Impossible de sauvegarder le préréglage &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="84"/>
        <source>Cannot rename preset &quot;{}&quot;</source>
        <translation>Impossible de renommer le préréglage &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="96"/>
        <source>Select Preset</source>
        <translation>Sélectionner le préréglage</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="109"/>
        <source>Preset already exists, overwrite?</source>
        <translation>Le préréglage existe déjà, l&apos;écraser ?</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="419"/>
        <source>Preset name</source>
        <translation>Nom du préréglage</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="211"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="212"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="213"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="214"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="217"/>
        <source>Export selected</source>
        <translation>Exporter le sélectionné</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="218"/>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="301"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="256"/>
        <source>The same name is already used!</source>
        <translation>Le même nom est déjà utilisé !</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="301"/>
        <source>Cannot create a cue from this preset: {}</source>
        <translation>Impossible de créer une cue depuis ce préréglage : {}</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="339"/>
        <source>Cannot export correctly.</source>
        <translation>Impossible d&apos;exporter correctement</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="351"/>
        <source>Some presets already exists, overwrite?</source>
        <translation>Certains préréglages existent déjà, les écraser ?</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="364"/>
        <source>Cannot import correctly.</source>
        <translation>Impossible d&apos;importer correctement.</translation>
    </message>
    <message>
        <location filename="../presets_ui.py" line="420"/>
        <source>Cue type</source>
        <translation>Type de cue</translation>
    </message>
</context>
</TS>
